.. _staticsite-examples:

########
Examples
########

Example uses of the :ref:`static site <mod-staticsite>` module


***********
Angular SPA
***********

To view an example deployment of an `Angular <https://angular.io/>`__ single page application, run ``runway gen-sample static-angular`` in any directory.
This will create a new ``static-angular/`` directory in your current working directory containing a ``runway.yml`` and a ``sample-app`` module that can be deployed.


*********
React SPA
*********

To view an example deployment of a `React <https://reactjs.org/>`__ single page application, run ``runway gen-sample static-react`` in any directory.
This will create a new ``static-react/`` directory in your current working directory containing a ``runway.yml`` and a ``sample-app`` module that can be deployed.
